@@ -2,17 +2,14 @@
 
 package Command::Do;
 {
-  $Command::Do::VERSION = '0.05';
+  $Command::Do::VERSION = '0.06';
 }
 
 use Validation::Class;
 use Validation::Class::Exporter;
-
 use Getopt::Long;
 
-use Command::Do::Directives;
-
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
  
 Validation::Class::Exporter->apply_spec(
     settings => [ base => [
@@ -61,12 +58,13 @@ build sub {
     
 };
 
-dir optspec => sub {1}; # noop
 # the optspec directive specifies the Getopt::Long option specification
 # for a given field
+dir optspec => sub {1}; #noop
 
 
 1;
+
 __END__
 =pod
 
@@ -76,7 +74,7 @@ Command::Do - The power of the Sun in the palm of your hand
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -121,13 +119,6 @@ or, ... use one CLI (command-line interface) to rule them all.
     
     use Command::Do;
     
-    set {
-        
-        # load child classes (commands)
-        classes => 1
-        
-    };
-    
     fld command => {
     
         required   => 1,
@@ -179,16 +170,77 @@ Command::Do is both simple, effective and anti-complicated. It is very
 unassumming and flexible. It does not impose a particular application
 configuration and its dependencies are trivial.
 
-It doesn't provide a mechanism for rendering help and/or command and options
-screens. The trend I'd recommend for that purpose is to simply display the
-command's POD, if that doesn't suit you, building your own help text rendering
-function is trivial.
+... sometimes you need an all-in-one command script:
 
-Command::Do is very minimalistic and tries to remain unassuming, each class
-field (see L<Validation::Class>) that is to be used as a command line option
-must have an C<optspec> directive defined. The optspec directive should be a
-valid L<Getopt::Long> option specification minus a name and aliases which are
-deduced from the field name and alias directive.
+    package yourcmd;
+    use Command::Do;
+    
+    mixin all  => {
+        filters => [qw/trim strip/]
+    };
+    
+    field file => {
+        mixin   => 'all',
+        optspec => 's@', # 100% Getopt::Long Compliant
+        alias   => ['f'] # directive is attached to the option spec
+    }; 
+    
+    # self-validating routines
+    method run => {
+    
+        input => ['file'],
+        using => sub {
+            
+            exit print join "\n", @{shift->file};
+            
+        }
+        
+    };
+    
+    yourcmd->run;
+
+... sometimes you need a suite of commands:
+
+    package yourcmd;
+    use YourCmd;
+    set
+    {
+        # each command is independent and can invoke sub-classes
+        classes => 1, # loads and registers yourcmd::*
+        
+    };
+    
+    # happens before new
+    build sub {
+        
+        my $self = shift;
+        
+        $self->{next_command} = shift @ARGV;
+        
+        return $self;
+        
+    };
+    
+    sub run {
+    
+        my $self = shift;
+        
+        my $next_command = $self->{next_command}; # e.g. sub_cmd
+        
+        # invokes other commands using the class method, see Validation::Class
+        my $sub = $self->class($next_command); # load lib/YourCmd/SubCmd.pm
+        
+        return $sub->run;
+        
+    };
+    
+    yourcmd->run;
+
+Please note: Command::Do is very minimalistic and tries to remain unassuming,
+each class field (see L<Validation::Class>) that is to be used as a command line
+option must have an C<optspec> directive defined. The optspec directive should
+be a valid L<Getopt::Long> option specification minus a name and aliases which
+are deduced from the field name and alias directive.
 
     package ...;
     use Command::Do;
